# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Document(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"id": "str", "url": "str", "focal_x": "float", "focal_y": "float"}

    attribute_map = {"id": "id", "url": "url", "focal_x": "focalX", "focal_y": "focalY"}

    def __init__(self, id=None, url=None, focal_x=None, focal_y=None):  # noqa: E501
        """Document - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._url = None
        self._focal_x = None
        self._focal_y = None
        self.discriminator = None
        self.id = id
        self.url = url
        if focal_x is not None:
            self.focal_x = focal_x
        if focal_y is not None:
            self.focal_y = focal_y

    @property
    def id(self):
        """Gets the id of this Document.  # noqa: E501

        The document id  # noqa: E501

        :return: The id of this Document.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Document.

        The document id  # noqa: E501

        :param id: The id of this Document.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def url(self):
        """Gets the url of this Document.  # noqa: E501

        The url to download the document  # noqa: E501

        :return: The url of this Document.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Document.

        The url to download the document  # noqa: E501

        :param url: The url of this Document.  # noqa: E501
        :type: str
        """
        if url is None:
            raise ValueError(
                "Invalid value for `url`, must not be `None`"
            )  # noqa: E501

        self._url = url

    @property
    def focal_x(self):
        """Gets the focal_x of this Document.  # noqa: E501

        The X coordinate of the focal point. Only applicable if the document is an image.  # noqa: E501

        :return: The focal_x of this Document.  # noqa: E501
        :rtype: float
        """
        return self._focal_x

    @focal_x.setter
    def focal_x(self, focal_x):
        """Sets the focal_x of this Document.

        The X coordinate of the focal point. Only applicable if the document is an image.  # noqa: E501

        :param focal_x: The focal_x of this Document.  # noqa: E501
        :type: float
        """

        self._focal_x = focal_x

    @property
    def focal_y(self):
        """Gets the focal_y of this Document.  # noqa: E501

        The Y coordinate of the focal point. Only applicable if the document is an image.  # noqa: E501

        :return: The focal_y of this Document.  # noqa: E501
        :rtype: float
        """
        return self._focal_y

    @focal_y.setter
    def focal_y(self, focal_y):
        """Sets the focal_y of this Document.

        The Y coordinate of the focal point. Only applicable if the document is an image.  # noqa: E501

        :param focal_y: The focal_y of this Document.  # noqa: E501
        :type: float
        """

        self._focal_y = focal_y

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(Document, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Document):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
