# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class EventLinkLabel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"type": "str", "value": "str", "icon": "str"}

    attribute_map = {"type": "type", "value": "value", "icon": "icon"}

    def __init__(self, type=None, value=None, icon=None):  # noqa: E501
        """EventLinkLabel - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._value = None
        self._icon = None
        self.discriminator = None
        self.type = type
        if value is not None:
            self.value = value
        if icon is not None:
            self.icon = icon

    @property
    def type(self):
        """Gets the type of this EventLinkLabel.  # noqa: E501

        The type of label. The default type is original-link. Some static types are defined and allow the client to display static labels and icons. When the link label is of type custom, it means that the client must use the value and icon returned by the API to display the link.   # noqa: E501

        :return: The type of this EventLinkLabel.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this EventLinkLabel.

        The type of label. The default type is original-link. Some static types are defined and allow the client to display static labels and icons. When the link label is of type custom, it means that the client must use the value and icon returned by the API to display the link.   # noqa: E501

        :param type: The type of this EventLinkLabel.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError(
                "Invalid value for `type`, must not be `None`"
            )  # noqa: E501
        allowed_values = [
            "custom",
            "registration",
            "videoconference",
            "recording",
            "original-link",
        ]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}".format(  # noqa: E501
                    type, allowed_values
                )
            )

        self._type = type

    @property
    def value(self):
        """Gets the value of this EventLinkLabel.  # noqa: E501

        The custom value of the link label to display.  # noqa: E501

        :return: The value of this EventLinkLabel.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this EventLinkLabel.

        The custom value of the link label to display.  # noqa: E501

        :param value: The value of this EventLinkLabel.  # noqa: E501
        :type: str
        """

        self._value = value

    @property
    def icon(self):
        """Gets the icon of this EventLinkLabel.  # noqa: E501

        The custom icon of the link label.  # noqa: E501

        :return: The icon of this EventLinkLabel.  # noqa: E501
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """Sets the icon of this EventLinkLabel.

        The custom icon of the link label.  # noqa: E501

        :param icon: The icon of this EventLinkLabel.  # noqa: E501
        :type: str
        """

        self._icon = icon

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(EventLinkLabel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventLinkLabel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
