# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class EventPage(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"layout": "Layout", "can_edit": "bool", "title": "str"}

    attribute_map = {"layout": "layout", "can_edit": "canEdit", "title": "title"}

    def __init__(self, layout=None, can_edit=None, title=None):  # noqa: E501
        """EventPage - a model defined in Swagger"""  # noqa: E501
        self._layout = None
        self._can_edit = None
        self._title = None
        self.discriminator = None
        self.layout = layout
        self.can_edit = can_edit
        self.title = title

    @property
    def layout(self):
        """Gets the layout of this EventPage.  # noqa: E501


        :return: The layout of this EventPage.  # noqa: E501
        :rtype: Layout
        """
        return self._layout

    @layout.setter
    def layout(self, layout):
        """Sets the layout of this EventPage.


        :param layout: The layout of this EventPage.  # noqa: E501
        :type: Layout
        """
        if layout is None:
            raise ValueError(
                "Invalid value for `layout`, must not be `None`"
            )  # noqa: E501

        self._layout = layout

    @property
    def can_edit(self):
        """Gets the can_edit of this EventPage.  # noqa: E501

        Whether the user doing the request can edit the event  # noqa: E501

        :return: The can_edit of this EventPage.  # noqa: E501
        :rtype: bool
        """
        return self._can_edit

    @can_edit.setter
    def can_edit(self, can_edit):
        """Sets the can_edit of this EventPage.

        Whether the user doing the request can edit the event  # noqa: E501

        :param can_edit: The can_edit of this EventPage.  # noqa: E501
        :type: bool
        """
        if can_edit is None:
            raise ValueError(
                "Invalid value for `can_edit`, must not be `None`"
            )  # noqa: E501

        self._can_edit = can_edit

    @property
    def title(self):
        """Gets the title of this EventPage.  # noqa: E501

        The event's title translated to the requested lang  # noqa: E501

        :return: The title of this EventPage.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this EventPage.

        The event's title translated to the requested lang  # noqa: E501

        :param title: The title of this EventPage.  # noqa: E501
        :type: str
        """
        if title is None:
            raise ValueError(
                "Invalid value for `title`, must not be `None`"
            )  # noqa: E501

        self._title = title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(EventPage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventPage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
