# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from .base_block import BaseBlock  # noqa: F401,E501


class BlockClientComputed(BaseBlock):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "legacy_widget_type": "str",
        "widget_type": "str",
        "properties": "object",
    }
    if hasattr(BaseBlock, "swagger_types"):
        swagger_types.update(BaseBlock.swagger_types)

    attribute_map = {
        "legacy_widget_type": "legacyWidgetType",
        "widget_type": "widgetType",
        "properties": "properties",
    }
    if hasattr(BaseBlock, "attribute_map"):
        attribute_map.update(BaseBlock.attribute_map)

    def __init__(
        self,
        legacy_widget_type=None,
        widget_type=None,
        properties=None,
        *args,
        **kwargs
    ):  # noqa: E501
        """BlockClientComputed - a model defined in Swagger"""  # noqa: E501
        self._legacy_widget_type = None
        self._widget_type = None
        self._properties = None
        self.discriminator = None
        if legacy_widget_type is not None:
            self.legacy_widget_type = legacy_widget_type
        if widget_type is not None:
            self.widget_type = widget_type
        if properties is not None:
            self.properties = properties
        BaseBlock.__init__(self, *args, **kwargs)

    @property
    def legacy_widget_type(self):
        """Gets the legacy_widget_type of this BlockClientComputed.  # noqa: E501

        DEPRECATED use widgetType instead.  # noqa: E501

        :return: The legacy_widget_type of this BlockClientComputed.  # noqa: E501
        :rtype: str
        """
        return self._legacy_widget_type

    @legacy_widget_type.setter
    def legacy_widget_type(self, legacy_widget_type):
        """Sets the legacy_widget_type of this BlockClientComputed.

        DEPRECATED use widgetType instead.  # noqa: E501

        :param legacy_widget_type: The legacy_widget_type of this BlockClientComputed.  # noqa: E501
        :type: str
        """

        self._legacy_widget_type = legacy_widget_type

    @property
    def widget_type(self):
        """Gets the widget_type of this BlockClientComputed.  # noqa: E501

        Used to identify the kind of widget that this block represents.  # noqa: E501

        :return: The widget_type of this BlockClientComputed.  # noqa: E501
        :rtype: str
        """
        return self._widget_type

    @widget_type.setter
    def widget_type(self, widget_type):
        """Sets the widget_type of this BlockClientComputed.

        Used to identify the kind of widget that this block represents.  # noqa: E501

        :param widget_type: The widget_type of this BlockClientComputed.  # noqa: E501
        :type: str
        """

        self._widget_type = widget_type

    @property
    def properties(self):
        """Gets the properties of this BlockClientComputed.  # noqa: E501

        The additional properties used by the client to render this block.  # noqa: E501

        :return: The properties of this BlockClientComputed.  # noqa: E501
        :rtype: object
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this BlockClientComputed.

        The additional properties used by the client to render this block.  # noqa: E501

        :param properties: The properties of this BlockClientComputed.  # noqa: E501
        :type: object
        """

        self._properties = properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(BlockClientComputed, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockClientComputed):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
